@@ -1,2 +1,2 @@
-`bpca` <-
+bpca <-
   function(x, ...) UseMethod('bpca', x)
