@@ -1,6 +1,8 @@
-oask <- devAskNewPage(dev.interactive(orNone = TRUE))
+oask <- devAskNewPage(dev.interactive(orNone=TRUE))
 
-bp <- bpca(rock, var.rb=TRUE, var.rd=TRUE)
+bp <- bpca(rock,
+           var.rb=TRUE,
+           var.rd=TRUE)
 summary(bp)
 
 # The total variance explained is satisfactory (>= .80)!
@@ -20,15 +22,19 @@ cor(rock)
 bp$var.rb
 
 # Aditional diagnostic
-plot(qbpca(rock, bp))
+plot(qbpca(rock,
+           bp))
 
 # This variable reamains as important in a dimension not contemplated
 # by the biplot reduction (PC3):
 
 bp$eigenvectors
 
-bp1 <- bpca(rock, lambda.ini=3, lambda.end=4)
+bp1 <- bpca(rock,
+            d=3:4)
+
 summary(bp1)
+
 plot(bp1)
 
 # The recommendation, knowing that this variable has a poor
@@ -36,15 +42,23 @@ plot(bp1)
 # 1- Avoid to discut it;
 # 2- Consider to incorporate the information with a bpca.3d
 
-bp2 <- bpca(rock, lambda.end=3, var.rb=TRUE, var.rd=TRUE)
+bp2 <- bpca(rock,
+            d=1:3,
+            var.rb=TRUE,
+            var.rd=TRUE)
+
 summary(bp2)
 
-plot(bp2)                # Static
-plot(bp2, rgl.use=TRUE)  # Dinamic
-bp2$var.rd               # nice
+plot(bp2)           # Static
+
+plot(bp2,
+     rgl.use=TRUE)  # Dinamic
+
+bp2$var.rd          # Nice!
 
 # Aditional diagnostic
-plot(qbpca(rock, bp2))
+plot(qbpca(rock,
+           bp2))
 
 devAskNewPage(oask)
 
